.. SPDX-FileCopyrightText: 2022 Calvin Walton
   
   SPDX-License-Identifier: MIT

API Reference
=============

:mod:`perfect_freehand` -- Draw perfect pressure-sensitive freehand lines
--------------------------------------------------------------------------

.. automodule:: perfect_freehand
    :no-members:

.. autofunction:: get_stroke

.. autofunction:: get_stroke_points

.. autofunction:: get_stroke_outline_points

:mod:`perfect_freehand.types` -- Support for Python type hints
--------------------------------------------------------------

.. automodule:: perfect_freehand.types
